# [Zope-tests] UNKNOWN : Zope-2.13 Python-2.6.5 : Linux

Zope Tests zope-tests at epy.co.at
Tue Feb 1 01:12:43 EST 2011

- Previous message: [Zope-tests] OK : Zope-2.12-alltests Python-2.6.5 : Linux
- Next message: [Zope-tests] OK : Zope-2.13-alltests Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    Zope Tests : UNKNOWN
    Zope-2.13 Python-2.6.5 : Linux (x86_64)

    Running ./bin/test --all
    /home/stefan/autotest/zope_runtests_4.sh: line 13: ./bin/test: No such file or directory

    UNKNOWN

    ----------------------------------------------------------------------------
    Results of the buildout step have been included below for debugging purposes
    ----------------------------------------------------------------------------

    Running /usr/local/python2.6/bin/python bootstrap.py
    Creating directory '/home/stefan/autotest/temp/python26-zope213/bin'.
    Creating directory '/home/stefan/autotest/temp/python26-zope213/parts'.
    Creating directory '/home/stefan/autotest/temp/python26-zope213/eggs'.
    Creating directory '/home/stefan/autotest/temp/python26-zope213/develop-eggs'.
    Generated script '/home/stefan/autotest/temp/python26-zope213/bin/buildout'.
    Running ./bin/buildout
    Setting socket time out to 60 seconds
    Getting distribution for 'mr.developer==1.16'.
    build/bdist.linux-x86_64/egg/mr/developer/svn.py:69: SyntaxWarning: name '_svn_version_warning' is used prior to global declaration
      global _svn_version_warning
    /home/stefan/autotest/temp/python26-zope213/eggs/tmpevoRCt/mr.developer-1.16-py2.6.egg/mr/developer/svn.py:69: SyntaxWarning: name '_svn_version_warning' is used prior to global declaration
      global _svn_version_warning
    /home/stefan/autotest/temp/python26-zope213/eggs/mr.developer-1.16-py2.6.egg/mr/developer/svn.py:69: SyntaxWarning: name '_svn_version_warning' is used prior to global declaration
      global _svn_version_warning
    /home/stefan/autotest/temp/python26-zope213/eggs/mr.developer-1.16-py2.6.egg/mr/developer/svn.py:69: SyntaxWarning: name '_svn_version_warning' is used prior to global declaration
      global _svn_version_warning
    Got mr.developer 1.16.
    Download error: [Errno -2] Name or service not known -- Some packages may not be found!
    Page at http://pypi.python.org/simple/argparse/ links to .py file(s) without version info; an index scan is required.
    Download error: [Errno -2] Name or service not known -- Some packages may not be found!
    Getting distribution for 'argparse==1.1'.
    zip_safe flag not set; analyzing archive contents...
    Got argparse 1.1.
    Develop: '/home/stefan/autotest/temp/python26-zope213/.'
    Getting distribution for 'zc.recipe.egg==1.2.2'.
    Got zc.recipe.egg 1.2.2.
    Getting distribution for 'zc.recipe.testrunner==1.2.1'.
    zip_safe flag not set; analyzing archive contents...
    Got zc.recipe.testrunner 1.2.1.
    Getting distribution for 'zope.testing==3.9.4'.
    warning: no files found matching 'sampletests' under directory 'src'
    Got zope.testing 3.9.4.
    Getting distribution for 'zope.interface==3.6.1'.
    Got zope.interface 3.6.1.
    Getting distribution for 'zope.exceptions==3.6.1'.
    Got zope.exceptions 3.6.1.
    Installing _mr.developer.
    Generated script '/home/stefan/autotest/temp/python26-zope213/bin/develop'.
    Installing test.
    Getting distribution for 'Products.StandardCacheManagers==2.13.0'.
    Got Products.StandardCacheManagers 2.13.0.
    Getting distribution for 'Products.PythonScripts==2.13.0'.
    Got Products.PythonScripts 2.13.0.
    Getting distribution for 'Products.MIMETools==2.13.0'.
    Got Products.MIMETools 2.13.0.
    Getting distribution for 'Products.MailHost==2.13.1'.
    Got Products.MailHost 2.13.1.
    Getting distribution for 'Products.ExternalMethod==2.13.0'.
    Got Products.ExternalMethod 2.13.0.
    Getting distribution for 'Products.BTreeFolder2==2.13.1'.
    Got Products.BTreeFolder2 2.13.1.
    Getting distribution for 'zope.viewlet==3.7.2'.
    Got zope.viewlet 3.7.2.
    Getting distribution for 'zope.traversing==3.13'.
    Got zope.traversing 3.13.
    Getting distribution for 'zope.testbrowser==3.10.3'.
    Got zope.testbrowser 3.10.3.
    Getting distribution for 'zope.tales==3.5.1'.
    Got zope.tales 3.5.1.
    Getting distribution for 'zope.tal==3.5.2'.
    Got zope.tal 3.5.2.
    Getting distribution for 'zope.structuredtext==3.5.0'.
    Got zope.structuredtext 3.5.0.
    Getting distribution for 'zope.size==3.4.1'.
    Got zope.size 3.4.1.
    Getting distribution for 'zope.site==3.9.2'.
    Got zope.site 3.9.2.
    Getting distribution for 'zope.sequencesort==3.4.0'.
    Got zope.sequencesort 3.4.0.
    Getting distribution for 'zope.sendmail==3.7.4'.
    Got zope.sendmail 3.7.4.
    Getting distribution for 'zope.security==3.7.4'.
    Got zope.security 3.7.4.
    Getting distribution for 'zope.schema==3.7.0'.
    Got zope.schema 3.7.0.
    Getting distribution for 'zope.publisher==3.12.4'.
    Got zope.publisher 3.12.4.
    Getting distribution for 'zope.ptresource==3.9.0'.
    Got zope.ptresource 3.9.0.
    Getting distribution for 'zope.proxy==3.6.1'.
    Got zope.proxy 3.6.1.
    Getting distribution for 'zope.processlifetime==1.0'.
    Got zope.processlifetime 1.0.
    Getting distribution for 'zope.pagetemplate==3.5.2'.
    Got zope.pagetemplate 3.5.2.
    Download error: [Errno 104] Connection reset by peer -- Some packages may not be found!
    Couldn't find index page for 'zope.location' (maybe misspelled?)
    Download error: [Errno 101] Network is unreachable -- Some packages may not be found!
    Getting distribution for 'zope.location==3.9.0'.
    While:
      Installing test.
      Getting distribution for 'zope.location==3.9.0'.
    Error: Couldn't find a distribution for 'zope.location==3.9.0'.

- Previous message: [Zope-tests] OK : Zope-2.12-alltests Python-2.6.5 : Linux
- Next message: [Zope-tests] OK : Zope-2.13-alltests Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list